ipykernel package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ipykernel.comm
   ipykernel.inprocess

Submodules
----------


.. automodule:: ipykernel.compiler
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.connect
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.control
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.debugger
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.displayhook
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.embed
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.eventloops
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.heartbeat
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.iostream
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.ipkernel
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.jsonutil
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.kernelapp
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.kernelbase
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.kernelspec
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.log
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.parentpoller
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.shellchannel
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.socket_pair
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.subshell
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.subshell_manager
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.thread
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.trio_runner
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: ipykernel.zmqshell
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ipykernel
   :members:
   :undoc-members:
   :show-inheritance:
